/**
 * Copyright Copyright 2008-14 Simon Andrews
 *
 *    This file is part of FocalPoint.
 *
 *    FocalPoint is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    FocalPoint is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with StackMeasure; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package uk.ac.bbsrc.babraham.FocalPoint.External;

import java.io.File;
import java.io.IOException;

public class DefaultLauncher {

	public static void openWithDefaultViewer (File file) throws IOException {
		
		/*
		 * This class is a bit of a hack.  We have to try to
		 * accommodate as many platforms as possible and
		 * launch the default application appropriately on all of them.
		 * 
		 * Eventually we should be able to replace this with calls
		 * to the awt.Desktop class.  Since this only arrived in
		 * Java 1.6 we can't rely on it yet though.
		 */
		
		if (System.getProperty("os.name").toLowerCase().indexOf("windows") >=0) {
			launchWindows(file);
		}
		else if (System.getProperty("os.name").toLowerCase().startsWith("mac os x")) {
			launchOSX(file);
		}
		else {
			throw new IOException("Don't know how to find default applications on this platform");
		}
		
		
	}
	
	private static void launchOSX (File file) throws IOException {
				
		String [] commandSet = {"open",file.getAbsolutePath()};
				
		Runtime.getRuntime().exec(commandSet);
	}

	private static void launchWindows (File file) throws IOException {

		/*
		 * The convoluted command line here is because start can take 1 or
		 * 2 arguments.  If there is only 1 and it's a filename with spaces
		 * in it then start thinks that's supposed to be the window title
		 * and launches a cmd window with that title.  Giving a blank first
		 * option forces the second option to be the filename.
		 */
		
		Runtime.getRuntime().exec("cmd /c start \"\" \""+file.getAbsolutePath()+"\"");
	}
	
	public static boolean canOpenDefaultOnThisPlatform () {
		if (System.getProperty("os.name").toLowerCase().indexOf("windows") >=0) {
			return true;
		}
		else if (System.getProperty("os.name").toLowerCase().startsWith("mac os x")) {
			return true;
		}
		else {
			return false;
		}
	}

	
}
