/**
 * Copyright Copyright 2008-14 Simon Andrews
 *
 *    This file is part of FocalPoint.
 *
 *    FocalPoint is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    FocalPoint is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with StackMeasure; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package uk.ac.bbsrc.babraham.FocalPoint.External;

import java.io.File;
import java.io.IOException;

import uk.ac.bbsrc.babraham.FocalPoint.Preferences.Preferences;

public class ImageJLauncher {

	public static void openImageWithImageJ (File file) throws IOException {
		
		/*
		 * This class is a bit of a hack.  We have to try to
		 * accommodate as many platforms as possible and
		 * launch ImageJ appropriately on all of them.
		 */
	
		// Check to see if they've specified an ImageJ location.
		// If they have then use that in preference to anything
		// else
		
		if (Preferences.getInstance().pathToImageJ() != null) {
			if (! Preferences.getInstance().pathToImageJ().exists()) {
				throw new IOException("ImageJ not found at set location '"+Preferences.getInstance().pathToImageJ()+"'");
			}
			Runtime.getRuntime().exec(new String [] {Preferences.getInstance().pathToImageJ().getAbsolutePath(),file.getAbsolutePath()});
			return;
		}
		
		// Only start guessing if they haven't specified an imagej location.
		
		if (System.getProperty("os.name").toLowerCase().indexOf("windows") >=0) {
			launchWindows(file);
		}
		else if (System.getProperty("os.name").toLowerCase().startsWith("mac os x")) {
			launchOSX(file);
		}
		else {
			launchOther(file);
		}
		
		
	}
	
	private static void launchOSX (File file) throws IOException {
		/*
		 * OSX is fairly easy as it will auto-discover ImageJ
		 * and we can use the 'start' command to launch it
		*/
				
		String [] commandSet = {"open","-a","imagej",file.getAbsolutePath()};
				
		Runtime.getRuntime().exec(commandSet);
	}

	private static void launchWindows (File file) throws IOException {
		/*
		 * For windows we'll have to assume that ImageJ is in
		 * the standard location of C:/Program Files/ImageJ
		 */
		
		File imageJProg = new File("C:/Program Files/ImageJ/imagej.exe");
		if (! file.exists()) {
			throw new IOException("Couldn't find the ImageJ.exe file");
		}
		
		Runtime.getRuntime().exec("\""+imageJProg.getAbsolutePath()+"\" \""+file.getAbsolutePath()+"\"");
	}


	private static void launchOther (File file) throws IOException {

		/*
		 * On other platforms we're going to assume that imagej is in the path
		 */
		
		String [] commandSet = {"imagej",file.getAbsolutePath()};
		
		Runtime.getRuntime().exec(commandSet);

	}
	
	public static boolean canUseImageJonThisPlatform () {
		if (Preferences.getInstance().pathToImageJ() != null) {
			if (Preferences.getInstance().pathToImageJ().exists()) {
				return true;
			}
		}
		
		// Only start guessing if they haven't specified an imagej location.
		
		if (System.getProperty("os.name").toLowerCase().indexOf("windows") >=0) {
			return true;
		}
		else if (System.getProperty("os.name").toLowerCase().startsWith("mac os x")) {
			return true;
		}
		else {
			return false;
		}

	}

	
}
